@@ -3,6 +3,8 @@ from .sphinxglue import exercise
 from .sphinxglue import task
 from .sphinxglue import taskstats
 from .sphinxglue import person
+from .sphinxglue import project
+from .sphinxglue import projectstats
 from .sphinxglue import scoretable
 from .sphinxglue import personstats
 from .sphinxglue import group
@@ -19,6 +21,8 @@ def setup(app):
     task.setup(app)
     taskstats.setup(app)
     person.setup(app)
+    project.setup(app)
+    projectstats.setup(app)
     scoretable.setup(app)
     personstats.setup(app)
     group.setup(app)
