@@ -26,4 +26,19 @@ class CompoundError(OpenTrainingError):
 
     def __init__(self, msg, errors, userdata):
         super().__init__(msg, userdata=userdata)
+        self.msg = msg
         self.errors = errors
+
+    def __str__(self):
+        msgs = [self.msg]
+        for e in self.errors:
+            msgs.append(' '*4 + str(e))
+        return '\n'.join(msgs)
+
+    def __iter__(self):
+        yield CompoundError(self.msg, errors=[], userdata=self.userdata)
+        for e in self.errors:
+            if isinstance(e, CompoundError):
+                yield from e
+            else:
+                yield e
